import logging
import os
from datetime import datetime, timedelta
from django_cron import CronJobBase, Schedule

from netguru.settings import FILE_SAVE_LOCATION
from .models import Share, SHARE_FILE

logger = logging.getLogger(__name__)


class ClearExpiredLinks(CronJobBase):
    RUN_EVERY_MINS = 60  # every 2 hours

    schedule = Schedule(run_every_mins=RUN_EVERY_MINS)
    code = 'clear-expired-links'  # a unique code

    def do(self):
        shares = Share.objects.filter(created_on__lt=datetime.now() - timedelta.days(1))
        for share in shares:
            if share.share_type == SHARE_FILE:
                path = os.path.join(FILE_SAVE_LOCATION, share.resource.split('.', 1)[0])
                if os.path.exists(path):
                    # we might have deleted in earlier and this call might have aborted with exception
                    # the transaction won't proceed so we might have already deleted this file
                    os.unlink(path)
        logger.info('Deleted expired shares')
